@@ -8,7 +8,7 @@ use Data::Validate::Domain qw( is_domain );
 use Data::Validate::Email qw( is_email );
 use URI;
 
-our $VERSION = 'v2.4.1'; # VERSION
+our $VERSION = 'v2.5.0'; # VERSION
 # ABSTRACT: WWW::eNom Moose Type Library
 
 use MooseX::Types -declare => [qw(
@@ -46,6 +46,7 @@ use MooseX::Types -declare => [qw(
     DomainAvailabilities
     DomainRegistration
     DomainTransfer
+    IRTPDetail
     PhoneNumber
     PrivateNameServer
     PrivateNameServers
@@ -133,6 +134,8 @@ subtype IPv6s, as ArrayRef[IPv6];
 subtype IP, as IPv4 | IPv6;
 subtype IPs, as ArrayRef[IP];
 
+class_type IRTPDetail, { class => 'WWW::eNom::IRTPDetail' };
+
 1;
 
 __END__
